(*
 * <COPYRIGHT>
 * Copyright 2005 Gerd Stolpmann
 *
 * <GPL>
 * This file is part of UMLMON.
 *
 * UMLMON is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * UMLMON is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with UMLMON; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 * </>
 *)

(* $Id: umlmon_client.mli 186 2005-10-14 10:41:50Z gerd $ *)

(** Contact UMLMON server using RPC *)

val create_client : ?prefer_local_socket:bool ->
                      ?prefer_redirection:bool ->
                    Unixqueue.event_system -> string -> Rpc_client.t
  (** [create_client ues id]: Creates an RPC client connected with the 
    * UMLMON server [id]. The string [id] may be the name of the monitor,
    * or may have the form "name@host" to contact a monitor running on the
    * remote [host]. The connection is unauthenticated (i.e. must still be
    * authenticated if TCP is used as transport).
    *
    * In [ues] pass the event system, e.g. simply the result of
    * [Unixqueue.create_unix_event_system()].
    *
    * [prefer_local_socket]: If true, the form "name@localhost" creates a connection
    * by Unix domain socket, and not by TCP. Default is false.
    *
    * [prefer_redirection]: If true, it is first checked whether the 
    * redirection service is available, and if so, it is used.
   *)

val need_authentication : Rpc_client.t -> bool
  (** [need_authentication client] returns [true] if the connection must be
    * authenticated, else [false].
   *)

val authenticate : ?userpw:bool -> Rpc_client.t -> string list -> bool
  (** [authenticate client passwords] authenticates the connection of [client]
    * with the [passwords]. Returns [true] on success.
    *
    * It is sufficient when one password of the list succeeds. There may be up to
    * two passwords.
    *
    * userpw: If true, only user passwords are accepted. Master passwords are not
    * checked.
   *)

val authenticate'async : ?userpw:bool -> Rpc_client.t -> string list -> 
                           ((unit -> bool) -> unit) -> unit
  (** The asynchronous version of [authenticate]. *)

val change_password : Rpc_client.t -> string -> string -> unit
  (** [change_password old_pw new_pw] changes the user password from [old_pw]
    * to [new_pw].
   *)
